=======
Credits
=======

Development Lead
----------------

* Guilherme Castelao <guilherme@castelao.net>

Contributors
------------

* Luiz Irber <luiz.irber@gmail.com>; Plenty suggestions suggestions and discussions.
* David Goldsmith <eulergaussriemann@gmail.com>; Edited overview.rst.
* Rohan Dandavati; Provided the CTD-bottle example file: MI18MHDR.btl
